@@ -33,8 +33,6 @@ plackettCopula <- function(param = NA_real_) {
 
 pplackettCopula <- function(u, copula) {
   dim <- copula@dimension
-  if(!is.matrix(u)) u <- rbind(u, deparse.level = 0L)
-  ## for (i in 1:dim) assign(paste("u", i, sep=""), u[,i])
   u1 <- u[,1]
   u2 <- u[,2]
   alpha <- copula@parameters[1]
@@ -45,8 +43,6 @@ pplackettCopula <- function(u, copula) {
 
 dplackettCopula <- function(u, copula, log = FALSE, ...) {
   dim <- copula@dimension
-  if(!is.matrix(u)) u <- rbind(u, deparse.level = 0L)
-  ## for (i in 1:dim) assign(paste("u", i, sep=""), u[,i])
   u1 <- u[,1]
   u2 <- u[,2]
   alpha <- copula@parameters[1]
